@@ -11,6 +11,11 @@ def create_project_name(num, client, name):
     return f"{num}_{client.upper()}_{name.upper()}"
 
 
+def get_yes_no(question):
+    answer = pick(["Yes", "No"], question)
+    return True if answer[1] == 0 else False
+
+
 def get_int_from_user(question):
     while True:
         try:
